@@ -2,7 +2,7 @@ package Devel::Examine::Subs;
 use warnings;
 use strict;
 
-our $VERSION = '1.35';
+our $VERSION = '1.36';
 
 BEGIN {
 
@@ -62,6 +62,7 @@ sub run {
         $struct = $self->_run_directory;
     }
     else {
+        $self->_end_of_line($self->{params}{file}) if $self->{params}{file};
         $struct = $self->_core($p);
     }
 
@@ -102,6 +103,9 @@ sub _run_directory {
     my %struct;
 
     for my $file (@files){
+        
+        $self->_end_of_line($file);
+
         $self->{params}{file} = $file;
         my $data = $self->_core($p);
 
@@ -114,6 +118,24 @@ sub _run_directory {
 
     return \%struct;
 }
+sub _end_of_line {
+    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+
+    my $self = shift;
+    my $file = shift;
+
+    $ENV{DES_EOL} = "\n";
+
+    return if $^O ne 'MSWin32';
+
+    tie my @tie_file, 'Tie::File', $file, recsep => $ENV{DES_EOL} or die $!;
+
+    if (@tie_file && $tie_file[0] =~ /\r\n/){
+        $ENV{DES_EOL} = "\r\n";
+    }
+
+    untie @tie_file;
+}
 sub _run_end {
     trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
 
@@ -475,7 +497,8 @@ sub _subs {
 
     return if ! $PPIsubs;
 
-    tie my @TIE_file, 'Tie::File', $file;
+    tie my @TIE_file, 'Tie::File', $file, recsep => $ENV{DES_EOL}
+      or die $!;
 
     my %subs;
     $subs{$file} = {};
@@ -950,7 +973,7 @@ sub add_functionality {
                                 });
 
     
-    tie my @TIE_file, 'Tie::File', $file
+    tie my @TIE_file, 'Tie::File', $file, recsep => $ENV{DES_EOL} 
       or croak "can't Tie::File the file $file: $!";
 
     my $end_line = $des->run;
